Learn R Programming

freqdom.fda (version 1.0.1)

fts.dpca.KLexpansion: Dynamic KL expansion

Description

Computes the dynamic KL expansion up to a given order.

Usage

fts.dpca.KLexpansion(X, dpcs = fts.dpca.filters(fts.spectral.density(X)))

Arguments

X

a functional time series given as an object of class fd.

dpcs

an object of class fts.timedom, representing the dpca filters obtained from the sample X. If dpsc = NULL, then dpcs = fts.dpca.filter(fts.spectral.density(X)) is used.

Value

An object of class fd.

Details

This function computes the \(L\)-order dynamic functional principal components expansion, defined by $$ \hat{X}_{t}^L(u):=\sum_{\ell=1}^L\sum_{k\in\mathbf{Z}} Y_{\ell,t+k} \phi_{\ell k}(u),\quad 1\leq L\leq d, $$ where \(\phi_{\ell k}(v)\) and \(d\) are explained in fts.dpca.filters and \(Y_{\ell k}\) are the dynamic functional PC scores as in fts.dpca.scores. For the sample version the sum extends over the range of lags for which the \(\phi_{\ell k}\) are defined.

For more details we refer to Hormann et al. (2015).

References

Hormann, S., Kidzinski, L., and Hallin, M. Dynamic functional principal components. Journal of the Royal Statistical Society: Series B (Statistical Methodology) 77.2 (2015): 319-348.

See Also

The multivariate equivalent in the freqdom package: dpca.KLexpansion