Learn R Programming

freqdom.fda (version 1.0.1)

fts.dpca.scores: Functional dynamic principal component scores

Description

Computes the dynamic principal component scores of a functional time series.

Usage

fts.dpca.scores(X, dpcs = fts.dpca.filters(spectral.density(X)))

Arguments

X

a functional time series given as an object of class fd.

dpcs

an object of class fts.timedom, representing the dpca filters obtained from the sample X. If dpsc = NULL, then dpcs = fts.dpca.filter(fts.spectral.density(X)) is used.

Value

A \((T\times \code{Ndpc})\)-matix with Ndpc = dim(dpcs$operators)[1]. The \(\ell\)-th column contains the \(\ell\)-th dynamic principal component score sequence.

Details

The \(\ell\)-th dynamic principal components score sequence is defined by $$ Y_{\ell t}:=\sum_{k\in\mathbf{Z}} \int_0^1 \phi_{\ell k}(v) X_{t-k}(v)dv,\quad 1\leq \ell\leq d, $$ where \(\phi_{\ell k}(v)\) and \(d\) are explained in fts.dpca.filters. (The integral is not necessarily restricted to the interval \([0,1]\), this depends on the data.) For the sample version the sum extends over the range of lags for which the \(\phi_{\ell k}\) are defined.

For more details we refer to Hormann et al. (2015).

References

Hormann, S., Kidzinski, L., and Hallin, M. Dynamic functional principal components. Journal of the Royal Statistical Society: Series B (Statistical Methodology) 77.2 (2015): 319-348.

See Also

The multivariate equivalent in the freqdom package: dpca.scores