fts.timedomCreates an object of class fts.timedom. This object corresponds to a sequence of linear operators.
fts.timedom(A, basisX, basisY = basisX)an object of class timedom.
an object of class basis.fd (see create.basis)
an object of class basis.fd (see create.basis)
Returns an object of class fts.freqdom. An object of class fts.freqdom is a list containing the following components:
operators \(\quad\) returns the array A$operators.
basisX \(\quad\) returns basisX as given in the argument.
basisY \(\quad\) returns basisY as given in the argument.
lags \(\quad\) returns A$lags.
This class is used to describe a functional linear filter, i.e. a sequence of linear operators, each of which corresponds to a certain lag.
Formally we consider an object of class timedom and add some basis functions. Depending on the context, we have different interpretations for the new object.
(I) In order to define operators which maps between two functions spaces, the we
interpret A$operators as coefficients in the basis function expansion of the
kernel of some finite rank operators $$\mathcal{A}_k:\mathrm{span}(\code{basisY})\to\mathrm{span}(\code{basisX}).$$ The kernels are \(a_k(u,v)=\boldsymbol{b}_1^\prime(u)\, A_k\, \boldsymbol{b}_2(v)\), where \(\boldsymbol{b_1}(u)=(b_{11}(u),\ldots, b_{1d_1}(u))^\prime\) and \(\boldsymbol{b_2}(u)=(b_{21}(u),\ldots, b_{2d_1}(u))^\prime\) are the basis functions provided by the arguments basisX and basisY, respectively. Moreover, we consider lags \(\ell_1<\ell_2<\cdots<\ell_K\). The object this function creates corresponds to the mapping \(\ell_k \mapsto a_k(u,v)\).
(II) We may ignore basisX, and represent the linear mapping $$\mathcal{A}_k:\mathrm{span}(\code{basisY})\to R^{d_1},$$ by considering \(a_k(v):=A_k\,\boldsymbol{b}_2(v)\) and \(\mathcal{A}_k(x)=\int a_k(v)x(v)dv\).
(III) We may ignore basisY, and represent the linear mapping $$\mathcal{A}_k: R^{d_1}\to\mathrm{span}(\code{basisX}),$$ by considering \(a_k(u):=\boldsymbol{b}_1^\prime(u)A_k\) and \(\mathcal{A}_k(y)=a_k(u)y\).
The multivariate equivalent in the freqdom package: timedom