Learn R Programming

freqdom.fda (version 1.0.1)

is.fts.freqdom: Checks if an object belongs to the class fts.freqdom

Description

Checks if an object belongs to the class fts.freqdom.

Usage

is.fts.freqdom(X)

Arguments

X

some object

Value

TRUE if X is of type fts.freqdom, FALSE otherwise

See Also

fts.freqdom, fts.timedom, is.fts.timedom