Learn R Programming

freqdom.fda (version 1.0.1)

is.fts.timedom: Checks if an object belongs to the class fts.timedom

Description

Checks if an object belongs to the class fts.timedom.

Usage

is.fts.timedom(X)

Arguments

X

some object

Value

TRUE if X is of type fts.timedom, FALSE otherwise

See Also

fts.freqdom, fts.timedom, is.fts.freqdom