Learn R Programming

freqdom.fda (version 1.0.1)

pm10: PM10 dataset

Description

Concentration of partical matter of diameter 10 micrometers or smaller (PM10) is one of the most widely adopted measurements for assesment of ambient air quality. In this dataset, we provide \(175\) measurement of daily temporal distribution of PM10 in Graz, Austria, collected between December 2004 and June 2005.

For the purpose of this R package, raw data of 48 observations per day, was transformed to functional objects in Fourier basis using fda package.

Usage

pm10

Arguments

Format

\(175\) daily distribution functions in the fd format from the fda package

References

Hormann, Siegfried, Brigitte Pfeiler, and Ernst Stadlober. Analysis and prediction of particulate matter PM10 for the winter season in Graz. Austrian Journal of Statistics 34.4 (2005): 307-326.

Examples

Run this code
# NOT RUN {
data(pm10)
summary(pm10)
plot(pm10)
# }

Run the code above in your browser using DataLab