Let \(X_1(u),\ldots, X_T(u)\) and \(Y_1(u),\ldots, Y_T(u)\) be two samples of functional data. This function determines empirical lagged covariances between the series \((X_t(u))\) and \((Y_t(u))\). More precisely it determines
$$
(\widehat{c}^{XY}_h(u,v)\colon h\in lags ),
$$
where \(\widehat{c}^{XY}_h(u,v)\) is the empirical version of the covariance kernel \(\mathrm{Cov}(X_h(u),Y_0(v))\).
For a sample of size \(T\) we set \(\hat\mu^X(u)=\frac{1}{T}\sum_{t=1}^T X_t(u)\) and
\(\hat\mu^Y(v)=\frac{1}{T}\sum_{t=1}^T Y_t(v)\). Now for \(h \geq 0\)
$$\frac{1}{T}\sum_{t=1}^{T-h} (X_{t+h}(u)-\hat\mu^X(u))(Y_t(v)-\hat\mu^Y(v))$$
and for \(h < 0\)
$$\frac{1}{T}\sum_{t=|h|+1}^{T} (X_{t+h}(u)-\hat\mu^X(u))(Y_t(v)-\hat\mu^Y(v)).$$
Since \(X_t(u)=\boldsymbol{b}_1^\prime(u)\mathbf{x}_t\) and \(Y_t(u)=\mathbf{y}_t^\prime \boldsymbol{b}_2(u)\) we can write
$$
\widehat{c}^{XY}_h(u,v)=\boldsymbol{b}_1^\prime(u)\widehat{C}^{\mathbf{xy}}\boldsymbol{b}_2(v),
$$
where \(\widehat{C}^{\mathbf{xy}}\) is defined as for the function ``cov.structure'' for series of coefficient vectors
\((\mathbf{x}_t\colon 1\leq t\leq T)\) and \((\mathbf{y}_t\colon 1\leq t\leq T)\).