Computes the proportion and cumulative proportion of variance explained by dynamic principal components.
fts.dpca.var(F)spectral density operator, provided as an object of class fts.freqdom. To guarantee accuracy of
numerical integration it is important that F$freq is a dense grid of frequencies in \([-\pi,\pi]\).
A vector containing the \(v_\ell\).
Consider a spectral density operator \(\mathcal{F}_\omega\) and let \(\lambda_\ell(\omega)\) by the \(\ell\)-th dynamic eigenvalue. The proportion of variance described by the \(\ell\)-th dynamic principal component is given as \(v_\ell:=\int_{-\pi}^\pi \lambda_\ell(\omega)d\omega/\int_{-\pi}^\pi \mathrm{tr}(\mathcal{F}_\omega)d\omega\). This function numerically computes the vectors \((v_\ell)\).
For more details we refer to Hormann et al. (2015).
Hormann, S., Kidzinski, L., and Hallin, M. Dynamic functional principal components. Journal of the Royal Statistical Society: Series B (Statistical Methodology) 77.2 (2015): 319-348.
The multivariate equivalent in the freqdom package: dpca.var